@@ -9,13 +9,14 @@
 ################################################################################
 
 import cppyy
-from libROOTPythonizations import AddTClassDynamicCastPyz
+from ROOT.libROOTPythonizations import AddTClassDynamicCastPyz
 
 
 def pythonize_tclass():
     klass = cppyy.gbl.TClass
 
     # DynamicCast
+    klass._TClass__DynamicCast = klass.DynamicCast
     AddTClassDynamicCastPyz(klass)
 
 # Instant pythonization (executed at `import ROOT` time), no need of a
